@@ -3,7 +3,7 @@ from menu.classes.exceptions import *
 try:
     from msvcrt import kbhit, getch
 except:
-    raise menuException(f'failed to import "msvcrt" module in {__file__}')
+    raise menu_import_exception(f'failed to import "msvcrt" module in {__file__}')
 
 __all__=[
     'clear_buffer'
@@ -16,6 +16,6 @@ def clear_buffer():
         while kbhit():
             getch()
     except:
-        raise menuException(f'failed to clear input buffer in file: {__file__}')
+        raise menu_import_exception(f'failed to clear input buffer in file: {__file__}')
     
     return
\ No newline at end of file
