@@ -3,7 +3,7 @@ from menu.classes.exceptions import *
 try:
     from os import system, name
 except:
-    raise menuException(f'failed to import "os" module in {__name__}')
+    raise menu_import_exception(f'failed to import "os" module in {__name__}')
 
 __all__=[
     'cls'
@@ -15,6 +15,6 @@ def cls():
     try:
         system('cls||clear')
     except:
-        raise menuException(f'critical error in cls() function in {__name__}.py')
+        raise menu_exception(f'critical error in cls() function in {__name__}.py')
 
     return
\ No newline at end of file
