@@ -3,20 +3,21 @@ import keyboard as k
 from time import sleep
 from platform import python_version, system, python_version_tuple
 from sys import setrecursionlimit
-from os import system
 
 # import functions
 from .functions.cls import *
 from .functions.print_header import *
 from .functions.clear_buffer import *
 from .functions.debugprint import *
+from .functions.check_types import *
+from .functions.menuprint import *
 
 # import classes
 from .classes.theme import *
 from .classes.exceptions import *
 from .classes.menu_options import *
 
-version = '0.2.49'
+version = '0.3.14'
 
 __all__=[
     'menu',
@@ -24,9 +25,9 @@ __all__=[
 ]
 
 choice = 1
-last_page = None
-last_teme = ''
-last_theme = ''
+_previous_pages = []
+_last_page = None
+_last_theme = ''
 
 #selection_delay = 0.22  # 0.22 seems best
 #refresh_rate = 0.01     # 0.01 seems appropriate
@@ -34,10 +35,15 @@ last_theme = ''
 # menu master class
 class menu(object):
 
-    def __init__(self, program_name):
+    tick_rate:float = 0.01          # variable refresh rate
+    selection_delay:float = 0.30    # variable selection delay
+
+    keybind_next:str = 's'          # keybind
+    keybind_prev:str = 'w'          # keybind
+    keybind_sel:str = 'enter'       # keybind
+
+    def __init__(self, program_name:str):
         self.name = program_name
-        self.tick_rate = 0.01
-        self.selection_delay = 0.30 
 
     def generate(self, page_name:str, menu_items:list, menu_text:list|str = None, theme:str = None):
 
@@ -55,24 +61,30 @@ class menu(object):
         #    menu_text = menu_text
 
         global choice     
-        global last_page
-        global last_theme
+        global _last_page
+        global _last_theme
 
         menu_text_list = []
+        bList = False
+
+        global _previous_pages
+        if page_name not in _previous_pages:
+            check_types(page_name, menu_items, menu_text, theme)
+            _previous_pages.append(page_name)
 
         # this ensures that when changing pages, the selection returns to the top of the page
-        if last_page != None:
-            if last_page != page_name:
+        if _last_page != None:
+            if _last_page != page_name:
                 choice = 1
         else:
             choice = 1
-        last_page = page_name
+        _last_page = page_name
 
         # only set the theme when applicable
-        if last_theme != theme:
+        if _last_theme != theme:
             if theme != None:
                 color_theme.set_theme(theme)             
-        last_theme = theme
+        _last_theme = theme
 
         # get the total amount of menu_options loaded into the menu, minus any "_skip_" or empty string options.
         # if the choice goes above or below the number of loaded menu items, return to 1 or total.
@@ -94,26 +106,25 @@ class menu(object):
         # format menu_text input
         if menu_text != None:
             if isinstance(menu_text, str) == True: # if menu_text is string
-                menu_text = f'{color_theme.text}{menu_text}{color_theme.end}'
+                formatted_menu_text = f'{color_theme.text}{menu_text}{color_theme.end}'
             elif isinstance(menu_text, list) == True: # if menu_text is list
+                bList = True
                 for item in menu_text:
                     if item in ['_skip_', '', ' ']:
                         menu_text_list.append('')
                         continue
                     menu_text_list.append(f'{color_theme.text}{item}{color_theme.end}')
-                menu_text = None
-            else:
-                raise menuException('menu_text *must* either be a string or a list')
 
         # if no menu options are present, raise exception (can't have a menu with no options, can you?).
         if len(menu_items) <= 0:
-            raise Exception('menu_items *must* contain at least one menu item')
+            raise menu_exception('menu_items *must* contain at least one menu item')
         
-        clear_buffer()                          # clear any buffered inputs
-        system('cls||clear')                    # clear terminal screen FIXME: this is causing flickering, there must be another way
+
+        clear_buffer()
+        cls()                                   # clear terminal screen FIXME: this is causing flickering, there must be another way
         print_header(self.name, page_name)      # print the menu header
-        if menu_text != None:
-            print(f' {menu_text}')
+        if bList == False:
+            print(f' {formatted_menu_text}')
         else:
             for item in menu_text_list:
                 print(f' {item}')
@@ -131,25 +142,23 @@ class menu(object):
                 else:
                     menu_option(i, item).print()
                 i += 1
-        else:
-            raise menuException('menu_items *must* be a list')
 
         # l00p until user selects an item in the menu
-        sleep(self.selection_delay)
-        while not k.is_pressed('enter'):
-            if k.is_pressed('s'):
+        sleep(menu.selection_delay)
+        while not k.is_pressed(menu.keybind_sel):
+            if k.is_pressed(menu.keybind_next):
                 try:
                     choice += 1
                     return self.generate(page_name, menu_items, menu_text, theme)
                 except:
                     return
-            elif k.is_pressed('w'):
+            elif k.is_pressed(menu.keybind_prev):
                 try:
                     choice -= 1
                     return self.generate(page_name, menu_items, menu_text, theme)
                 except:
-                    self.terminate()
-            sleep(self.tick_rate)
+                    return
+            sleep(menu.tick_rate)
         
         clear_buffer()
         return menu_option(choice, menu_items[choice-1], menu_items[choice-1]).select()
@@ -161,9 +170,9 @@ class menu(object):
 
 #check that user is using the correct OS and version of python
 if system().lower() != 'windows':
-    raise menuException(f'invalid operating system: "{system()}"\nmenu.py currently only works on windows machines.')
+    raise menu_exception(f'invalid operating system: "{system()}"\nmenu.py currently only works on windows machines.')
 if int(python_version_tuple()[0]) < 3 or int(python_version_tuple()[1]) < 6:
-    raise menuException(f'invalid python version: "{python_version()}"\nmenu.py makes use of features, such as f-strings, that require python 3.6 or newer.')
+    raise menu_exception(f'invalid python version: "{python_version()}"\nmenu.py makes use of features, such as f-strings, that require python 3.6 or newer.')
 
 try:
     setrecursionlimit(10**6)
